import { Except } from 'type-fest';
import { BasicMetaSysProps, DefaultElements, MakeRequest, SysLink } from '../common-types';
import { ParameterDefinition } from './widget-parameters';
declare type AppActionSys = Except<BasicMetaSysProps, 'version'> & {
    appDefinition: SysLink;
    organization: SysLink;
};
export declare type AppActionParameterDefinition = Omit<ParameterDefinition, 'labels'>;
export declare enum AppActionCategoryType {
    EntriesV1 = "Entries.v1.0",
    NotificationV1 = "Notification.v1.0",
    Custom = "Custom"
}
export declare type AppActionCategoryProps = {
    sys: {
        id: AppActionCategoryType;
        type: 'AppActionCategory';
        version: string;
    };
    name: string;
    description: string;
    parameters?: AppActionParameterDefinition[];
};
declare type BuiltInCategoriesProps = {
    /**
     * Category identifying the shape of the action.
     */
    category: AppActionCategoryType.EntriesV1 | AppActionCategoryType.NotificationV1;
};
declare type CustomAppActionProps = {
    /**
     * "Custom" category requires "parameters"
     */
    category: AppActionCategoryType.Custom;
    parameters: AppActionParameterDefinition[];
};
declare type AppActionCategory = BuiltInCategoriesProps | CustomAppActionProps;
export declare type CreateAppActionProps = AppActionCategory & {
    url: string;
    name: string;
    description?: string;
};
export declare type AppActionProps = AppActionCategory & {
    /**
     * System metadata
     */
    sys: AppActionSys;
    /**
     * Url that will be called when the action is invoked
     */
    url: string;
    /**
     * Human readable name for the action
     */
    name: string;
    /**
     * Human readable description of the action
     */
    description?: string;
};
export declare type AppAction = AppActionProps & DefaultElements<AppActionProps> & {
    /**
     * Deletes this object on the server.
     * @return Promise for the deletion. It contains no data, but the Promise error case should be handled.
     * @example ```javascript
     * const contentful = require('contentful-management')
     *
     * const client = contentful.createClient({
     *   accessToken: '<content_management_api_key>'
     * })
     *
     * client.getOrganization('<org_id>')
     * .then((org) => org.getAppDefinition('<app_def_id>'))
     * .then((appDefinition) => appDefinition.getAppAction('<app-action-id>'))
     * .then((appAction) => appAction.delete())
     * .catch(console.error)
     * ```
     */
    delete(): Promise<void>;
};
/**
 * @private
 * @param makeRequest - function to make requests via an adapter
 * @param data - Raw App Bundle data
 * @return Wrapped App Bundle data
 */
export declare function wrapAppAction(makeRequest: MakeRequest, data: AppActionProps): AppAction;
/**
 * @private
 * @param makeRequest - function to make requests via an adapter
 * @param data - Raw App Bundle collection data
 * @return Wrapped App Bundle collection data
 */
export declare const wrapAppActionCollection: (makeRequest: MakeRequest, data: import("../common-types").CollectionProp<AppActionProps>) => import("../common-types").Collection<AppAction, AppActionProps>;
export {};
